@@ -7,7 +7,7 @@ from jsonpath_ng.ext import parse
 from loguru import logger
 from pygments import highlight, lexers, formatters
 
-__version__ = '0.8.4'
+__version__ = '0.8.5'
 parser = None
 
 
@@ -16,7 +16,8 @@ def get_args():
     parser = argparse.ArgumentParser(description='%(prog)s v' + __version__ + ' - Process a JSONPath expression over a JSON read from <stdin>.')
     parser.add_argument('jsonpath', help='valid jsonpath expression', nargs='?', default='$')
     parser.add_argument('-c', '--color', help='enable/disable colored highlights', action=argparse.BooleanOptionalAction, default=True)
-    parser.add_argument('-f', '--format', '-i', '--indent', help='enable/disable formatting output', action=argparse.BooleanOptionalAction, default=False)
+    parser.add_argument('-f', '--format', help='enable/disable formatting output', action=argparse.BooleanOptionalAction, default=False)
+    parser.add_argument('-i', '--indent', help='number of spaces for indent on formatting', default=4)
     parser.add_argument('-v', '--version', action='version', version='%(prog)s v' + __version__)
 
     args = parser.parse_args()
@@ -43,10 +44,11 @@ def colorize(json_data):
     return highlight(json_data, lexers.JsonLexer(), formatters.TerminalFormatter()).strip()
 
 
-def print_results(results, color, format):
+def print_results(results, color, formatting, indent=2):
+    logger.info("indent {}", indent)
     for result in results:
         logger.trace(f'json parsing result: {result} {type(result)}')
-        output = json.dumps(result, indent=3) if format else json.dumps(result)
+        output = json.dumps(result, indent=int(indent)) if formatting else json.dumps(result)
         print(colorize(output) if color else output)
 
 
@@ -55,7 +57,7 @@ def main():
         args = get_args()
         colored = sys.stdout.isatty() and args.color
         for data in read_input():
-            print_results([x.value for x in parse(args.jsonpath).find(data)], colored, args.format)
+            print_results([x.value for x in parse(args.jsonpath).find(data)], colored, args.format, args.indent)
 
     except Exception as e:
         print(e, file=sys.stderr)
